###########
Champollion
###########

.. image:: https://img.shields.io/pypi/v/champollion.svg
        :target: https://pypi.python.org/pypi/champollion

.. image:: https://api.travis-ci.org/buddly27/champollion.svg?branch=master
    :target: https://travis-ci.org/buddly27/champollion

.. image:: https://coveralls.io/repos/github/buddly27/champollion/badge.svg?branch=master
    :target: https://coveralls.io/github/buddly27/champollion?branch=master

.. image:: https://readthedocs.org/projects/champollion/badge/?version=stable
        :target: http://champollion.readthedocs.io/en/stable
        :alt: Documentation Status

Sphinx extension which provides an automatic way to document javascript code

*************
Documentation
*************

Full documentation, including installation and setup guides, can be found at
http://champollion.readthedocs.io/en/stable/

*********************
Copyright and license
*********************

Copyright (c) 2017 Jeremy Retailleau

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this work except in compliance with the License. You may obtain a copy of the
License in the LICENSE.txt file, or at:

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
